==> CoffeeMud_5_9_6.zip: com/planet_ink/coffee_mud/Locales/SaltWaterSurfaceColumn.java <==
package com.planet_ink.coffee_mud.Locales;
import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

import java.util.*;

/*
   Copyright 2016-2017 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
public class SaltWaterSurfaceColumn extends WaterSurfaceColumn
{
	@Override
	public String ID()
	{
		return "SaltWaterSurfaceColumn";
	}

	public SaltWaterSurfaceColumn()
	{
		super();
	}

	@Override
	protected String UnderWaterLocaleID()
	{
		return "UnderSaltWaterColumnGrid";
	}

	@Override
	protected boolean IsUnderWaterFatClass(Room thatSea)
	{
		return (thatSea instanceof UnderSaltWaterGrid) 
			|| (thatSea instanceof UnderSaltWaterColumnGrid) 
			|| (thatSea instanceof UnderSaltWaterThinGrid);
	}

	@Override
	public List<Integer> resourceChoices()
	{
		return SaltWaterSurface.roomResources;
	}
}

==> CoffeeMud_5_9_8.zip: com/planet_ink/coffee_mud/Locales/SaltWaterSurfaceColumn.java <==
package com.planet_ink.coffee_mud.Locales;
import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

import java.util.*;

/*
   Copyright 2016-2019 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
public class SaltWaterSurfaceColumn extends WaterSurfaceColumn
{
	@Override
	public String ID()
	{
		return "SaltWaterSurfaceColumn";
	}

	public SaltWaterSurfaceColumn()
	{
		super();
	}

	@Override
	protected String UnderWaterLocaleID()
	{
		return "UnderSaltWaterColumnGrid";
	}

	@Override
	protected boolean IsUnderWaterFatClass(final Room thatSea)
	{
		return (thatSea instanceof UnderSaltWaterGrid)
			|| (thatSea instanceof UnderSaltWaterColumnGrid)
			|| (thatSea instanceof UnderSaltWaterThinGrid);
	}

	@Override
	public List<Integer> resourceChoices()
	{
		return SaltWaterSurface.roomResources;
	}
}
